@@ -3,7 +3,7 @@
  *                                                                           *
  * Reads an Taylor-UUCP Log-/Statsfile, and generates a report out of it     *
  *                                                                           *
- * uutraf.c is (c) David Frey, 1995    					     *
+ * uutraf.c is (c) David Frey, 1995					     *
  *								             *
  * Modifications by Yves Arrouye, 1996                                       *
  *								             *
@@ -57,12 +57,10 @@ static struct option const long_options[] =
 char *progname;					 /* name of the program */
 hostentry *hosttab;				 /* linked list of hosts */
 
-extern int errno;
-
 time_t startlogtime, stoplogtime;
 
 void AnalyzeLogfile(char *logfilename, int newsstats)
-/* 
+/*
  * Analyze the Logfile. We got the file statistice already out of the
  * Stats-file.
  */
@@ -339,8 +337,8 @@ void AnalyzeLogfile(char *logfilename, int newsstats)
 }
 
 void PrintResults(hostentry * hosttab, int newsstats)
-/* 
- * Output out results 
+/*
+ * Output out results
  */
 {
   hostentry *h;
@@ -587,7 +585,7 @@ int main(int argc, char *argv[])
 
 #endif
 
-  char c;
+  int c;
 
   char logfilename[FILENAME_MAX], statsfilename[FILENAME_MAX];
 
